@@ -10,7 +10,6 @@ LOGF=make.gluegen.all.android-armv6-cross.log
 rm -f ${LOGF}
 
 export ANDROID_HOME=/opt-linux-x86_64/android-sdk-linux_x86_64
-export ANDROID_API_LEVEL=24
 export ANDROID_HOST_TAG=linux-x86_64
 export ANDROID_ABI=armeabi-v7a
 
@@ -42,10 +41,6 @@ export TARGET_ADB_PORT=5555
 export TARGET_ROOT=/data/projects
 export TARGET_ANT_HOME=/usr/share/ant
 
-export SOURCE_LEVEL=1.8
-export TARGET_LEVEL=1.8
-export TARGET_RT_JAR=/opt-share/jre1.8.0_212/lib/rt.jar
-
 #export JUNIT_DISABLED="true"
 #export JUNIT_RUN_ARG0="-Dnewt.test.Screen.disableScreenMode"
 
