@@ -15,10 +15,6 @@ fi
 #    -Dgluegen-cpptasks.file=`pwd`/lib/gluegen-cpptasks-linux-32bit.xml \
 #
 
-export SOURCE_LEVEL=1.8
-export TARGET_LEVEL=1.8
-export TARGET_RT_JAR=/opt-share/jre1.8.0_212/lib/rt.jar
-
 export GLUEGEN_PROPERTIES_FILE="lib/gluegen-clang.properties"
 # or -Dgcc.compat.compiler=clang
 
