@@ -4,23 +4,16 @@ if [ -e /usr/local/etc/profile.ant ] ; then
     . /usr/local/etc/profile.ant
 fi
 
-#    -Dc.compiler.debug=true 
+#    -Dc.compiler.debug=true
 #
-#    -Dtarget.sourcelevel=1.6 \
-#    -Dtarget.targetlevel=1.6 \
-#    -Dtarget.rt.jar=/opt-share/jre1.6.0_30/lib/rt.jar \
 
 # Force OSX SDK 10.6, if desired
 # export SDKROOT=macosx10.6
 
-JAVA_HOME=`/usr/libexec/java_home -version 17`
+JAVA_HOME=`/usr/libexec/java_home -version 21`
 PATH=$JAVA_HOME/bin:$PATH
 export JAVA_HOME PATH
 
-export SOURCE_LEVEL=1.8
-export TARGET_LEVEL=1.8
-export TARGET_RT_JAR=/usr/local/jre1.8.0_212/lib/rt.jar
-
 #export JOGAMP_JAR_CODEBASE="Codebase: *.jogamp.org"
 export JOGAMP_JAR_CODEBASE="Codebase: *.goethel.localnet"
 
