@@ -3,7 +3,7 @@
 builddir="$1"
 shift
 
-if [ -z "$builddir" ] ; then 
+if [ -z "$builddir" ] ; then
     echo Usage $0 build-dir
     exit 1
 fi
@@ -28,6 +28,14 @@ if [ -z "$ANT_PATH" ] ; then
         echo autosetting ANT_PATH to $ANT_PATH
     fi
 fi
+# FreeBSD
+if [ -z "$ANT_PATH" ] ; then
+    if [ -e /usr/local/bin/ant -a -e /usr/local/share/java/apache-ant/lib/ant.jar ] ; then
+        ANT_PATH=/usr/local/share/java/apache-ant
+        export ANT_PATH
+        echo autosetting ANT_PATH to $ANT_PATH
+    fi
+fi
 if [ -z "$ANT_PATH" ] ; then
     echo ANT_PATH does not exist, set it
     print_usage
@@ -43,9 +51,13 @@ GLUEGEN_ROOT=`dirname $builddir`
 ROOTREL_BUILD=`basename $builddir`
 builddirAbs=`readlink -f $builddir`
 
+# We use TempJarCache per default now!
+export USE_NATIVELIBDIR=0
+#export USE_NATIVELIBDIR=1
+
 # MODULE_ARGS="--illegal-access=warn"
-# MODULE_ARGS="--add-opens java.base/java.lang=ALL-UNNAMED --add-opens java.desktop/sun.awt=ALL-UNNAMED --add-opens java.desktop/sun.java2d=ALL-UNNAMED"
-MODULE_ARGS="--add-opens java.desktop/sun.awt=ALL-UNNAMED --add-opens java.desktop/sun.java2d=ALL-UNNAMED"
+# MODULE_ARGS="--enable-native-access=ALL-UNNAMED --add-opens java.base/java.lang=ALL-UNNAMED --add-opens java.desktop/sun.awt=ALL-UNNAMED --add-opens java.desktop/sun.java2d=ALL-UNNAMED"
+MODULE_ARGS="--enable-native-access=ALL-UNNAMED --add-opens java.desktop/sun.awt=ALL-UNNAMED --add-opens java.desktop/sun.java2d=ALL-UNNAMED"
 
 X_ARGS="-Drootrel.build=$ROOTREL_BUILD -Dgluegen.root=$GLUEGEN_ROOT"
 
@@ -74,37 +86,42 @@ X_ARGS="-Drootrel.build=$ROOTREL_BUILD -Dgluegen.root=$GLUEGEN_ROOT"
 #D_ARGS="-Djogamp.debug.ByteBufferInputStream"
 #D_ARGS="-Djogamp.debug.Buffers"
 #D_ARGS="-Djogamp.debug.Bitstream"
+#D_ARGS="-Djogamp.debug.UnsafeUtil"
 #D_ARGS="-Djogamp.debug=all"
 #D_ARGS="-Djogamp.debug.Logging"
 
 function onetest() {
-    #USE_CLASSPATH=lib/junit.jar:$ANT_JARS:lib/semantic-versioning/semver.jar:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/gluegen-rt.jar:"$builddir"/gluegen.jar:"$builddir"/gluegen-test-util.jar:"$builddir"/test/build/gluegen-test.jar:../jcpp/lib/guava-32.1.2-jre.jar
-    USE_CLASSPATH=lib/junit.jar:$ANT_JARS:lib/semantic-versioning/semver.jar:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/gluegen-rt.jar:"$builddir"/gluegen.jar:"$builddir"/gluegen-test-util.jar:"$builddir"/test/build/gluegen-test.jar:"$builddir"/gluegen-rt-natives.jar:../jcpp/lib/guava-32.1.2-jre.jar
-    #USE_CLASSPATH=lib/junit.jar:$ANT_JARS:lib/semantic-versioning/semver.jar:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/gluegen-rt-alt.jar:"$builddir"/gluegen.jar:"$builddir"/gluegen-test-util.jar:"$builddir"/test/build/gluegen-test.jar:../jcpp/lib/guava-32.1.2-jre.jar
+    #USE_CLASSPATH=lib/junit.jar:$ANT_JARS:lib/japicmp/japicmp-with-dependencies.jar:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/gluegen-rt.jar:"$builddir"/gluegen.jar:"$builddir"/gluegen-test-util.jar:"$builddir"/test/build/gluegen-test.jar:../jcpp/lib/guava-32.1.2-jre.jar
+    USE_CLASSPATH=lib/junit.jar:$ANT_JARS:lib/japicmp/japicmp-with-dependencies.jar:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/gluegen-rt.jar:"$builddir"/gluegen.jar:"$builddir"/gluegen-test-util.jar:"$builddir"/test/build/gluegen-test.jar:"$builddir"/gluegen-rt-natives.jar:../jcpp/lib/guava-32.1.2-jre.jar
+    #USE_CLASSPATH=lib/junit.jar:$ANT_JARS:lib/japicmp/japicmp-with-dependencies.jar:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/gluegen-rt-alt.jar:"$builddir"/gluegen.jar:"$builddir"/gluegen-test-util.jar:"$builddir"/test/build/gluegen-test.jar:../jcpp/lib/guava-32.1.2-jre.jar
     #USE_CLASSPATH=lib/junit.jar:$ANT_JARS:"$builddir"/../make/lib/TestJarsInJar.jar:"$builddir"/classes:"$builddir"/test/build/classes:../jcpp/lib/guava-32.1.2-jre.jar
-    #libspath="${builddirAbs}"/test/build/natives
-    libspath="${builddirAbs}"/obj:"${builddirAbs}"/test/build/natives
-    LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$libspath
-    DYLD_LIBRARY_PATH=$DYLD_LIBRARY_PATH:$libspath
-    export LD_LIBRARY_PATH DYLD_LIBRARY_PATH
-    echo LD_LIBRARY_PATH $LD_LIBRARY_PATH
-    echo DYLD_LIBRARY_PATH $DYLD_LIBRARY_PATH
-    echo USE_CLASSPATH $USE_CLASSPATH
     which java
-    echo java $MODULE_ARGS $X_ARGS -Djava.library.path=$libspath -cp "$USE_CLASSPATH" $D_ARGS $*
-    java $MODULE_ARGS $X_ARGS -Djava.library.path="$libspath" -cp "$USE_CLASSPATH" $D_ARGS $*
-    #echo java -cp "$USE_CLASSPATH" $X_ARGS $D_ARGS $*
-    #java -cp "$USE_CLASSPATH" $X_ARGS $D_ARGS $*
-    #j3 -cp "$USE_CLASSPATH" $X_ARGS $D_ARGS $*
+    if [ $USE_NATIVELIBDIR -eq 1 ] ; then
+        #libspath="${builddirAbs}"/test/build/natives
+        libspath="${builddirAbs}"/obj:"${builddirAbs}"/test/build/natives
+        LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$libspath
+        DYLD_LIBRARY_PATH=$DYLD_LIBRARY_PATH:$libspath
+        export LD_LIBRARY_PATH DYLD_LIBRARY_PATH
+        echo LD_LIBRARY_PATH $LD_LIBRARY_PATH
+        echo DYLD_LIBRARY_PATH $DYLD_LIBRARY_PATH
+        echo USE_CLASSPATH $USE_CLASSPATH
+        echo java $MODULE_ARGS $X_ARGS -Djava.library.path=$libspath -cp "$USE_CLASSPATH" $D_ARGS $*
+        java $MODULE_ARGS $X_ARGS -Djava.library.path="$libspath" -cp "$USE_CLASSPATH" $D_ARGS $*
+    else
+        echo USE_CLASSPATH $USE_CLASSPATH
+        echo java $MODULE_ARGS $X_ARGS $D_ARGS -cp "$USE_CLASSPATH" $*
+        java $MODULE_ARGS $X_ARGS $D_ARGS -cp "$USE_CLASSPATH" $*
+    fi
     echo
 }
 #
-#onetest com.jogamp.common.GlueGenVersion 2>&1 | tee -a $LOG
+onetest com.jogamp.common.GlueGenVersion 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestSystemPropsAndEnvs 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestVersionInfo 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestVersionNumber 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestVersionSemantics 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestIteratorIndexCORE 2>&1 | tee -a $LOG
+#onetest com.jogamp.common.util.TestUnsafeUtil 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.locks.TestRecursiveLock01 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.locks.TestRecursiveThreadGroupLock01 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.locks.TestSingletonServerSocket00 2>&1 | tee -a $LOG
@@ -119,6 +136,7 @@ function onetest() {
 #onetest com.jogamp.common.util.TestLongIntHashMap 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestPlatform01 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestRunnableTask01 2>&1 | tee -a $LOG
+#onetest com.jogamp.common.util.TestWorkerThread01 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestIOUtil01 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestTempJarCache 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestJarUtil 2>&1 | tee -a $LOG
@@ -131,6 +149,7 @@ function onetest() {
 #onetest com.jogamp.common.util.TestBitstream02 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestBitstream03 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.util.TestBitstream04 2>&1 | tee -a $LOG
+#onetest com.jogamp.common.util.TestStringUtil 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.net.TestUrisWithAssetHandler 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.net.TestUriQueryProps 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.net.TestUri01 2>&1 | tee -a $LOG
@@ -148,9 +167,10 @@ function onetest() {
 #onetest com.jogamp.common.nio.TestByteBufferOutputStream 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.nio.TestByteBufferCopyStream 2>&1 | tee -a $LOG
 #onetest com.jogamp.common.os.TestElfReader01 $* 2>&1 | tee -a $LOG
+#onetest com.jogamp.common.os.TestClock01 $* 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.test.junit.internals.TestType 2>&1 | tee -a $LOG
 
-onetest com.jogamp.gluegen.test.junit.generation.TestJCPP $* 2>&1 | tee -a $LOG
+#onetest com.jogamp.gluegen.test.junit.generation.TestJCPP $* 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.test.junit.generation.TestCParser $* 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.jcpp.CppReaderTest 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.jcpp.ErrorTest 2>&1 | tee -a $LOG
@@ -165,7 +185,6 @@ onetest com.jogamp.gluegen.test.junit.generation.TestJCPP $* 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.jcpp.TokenPastingWhitespaceTest 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.jcpp.VaArgsPastingTest 2>&1 | tee -a $LOG
 
-
 #onetest com.jogamp.gluegen.test.junit.generation.Test1p1JavaEmitter 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.test.junit.generation.Test1p2ProcAddressEmitter 2>&1 | tee -a $LOG
 #onetest com.jogamp.gluegen.test.junit.generation.Test1p2LoadJNIAndImplLib 2>&1 | tee -a $LOG
