@@ -1,13 +1,15 @@
 #! /bin/sh
 
-# Aligned with Android SDK build-tools 29 and NDK 20 as of 2019-12-10
+# set -x
+
+# Aligned with Android SDK build-tools 36 and NDK 29 as of 2025-06-25
 #
 # As it is no more easily achievable to download the complete SDK 
 # separately, I used Android-Studio to fetch all parts incl. the NDK.
 # Thereafter I copied ~/Android/Sdk -> /opt-linux-x86_64/android-sdk-linux_x86_64
 # which I also use for the official crosscompilation.
 #
-# Variable names borrowed from ~/Android/Sdk/ndk/20.1.5948944/build/cmake/android.toolchain.cmake
+# Variable names borrowed from ~/Android/Sdk/ndk/29.0.13599879/build/cmake/android.toolchain.cmake
 # We only use ANDROID_API_LEVEL instead of ANDROID_PLATFORM_LEVEL, as it describes the API level.
 #
 #
@@ -20,7 +22,7 @@
 #        /opt/android-sdk-linux_x86_64
 #        /usr/local/android-sdk-linux_x86_64
 #
-# - ANDROID_API_LEVEL - defaults to 24
+# - ANDROID_API_LEVEL - defaults to 26
 #
 # - ANDROID_HOST_TAG - defaults to linux-x86_64
 #
@@ -40,8 +42,6 @@
 # - ANDROID_NDK
 # - ANDROID_BUILDTOOLS_ROOT
 # - ANDROID_TOOLCHAIN_ROOT
-# - ANDROID_TOOLCHAIN_SYSROOT0
-# - ANDROID_TOOLCHAIN_SYSROOT0_LIB
 # - ANDROID_TOOLCHAIN_SYSROOT1
 # - ANDROID_TOOLCHAIN_SYSROOT1_INC
 # - ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH
@@ -52,36 +52,27 @@
 # Android Studio SDK + NDK Filesystem Layout (official)
 #
 # ~/Android/Sdk/
-# ~/Android/Sdk/build-tools/29.0.2/
-# ~/Android/Sdk/build-tools/29.0.2/zipalign (*)
+# ~/Android/Sdk/build-tools/36.0.0/
+# ~/Android/Sdk/build-tools/36.0.0/zipalign (*)
 # ~/Android/Sdk/ndk/
-# ~/Android/Sdk/ndk/20.1.5948944/platforms/android-24/arch-arm64 (1)
-# ~/Android/Sdk/ndk/20.1.5948944/platforms/android-24/arch-arm64/usr/lib/libc.a (*)(1)
-# ~/Android/Sdk/ndk/20.1.5948944/sysroot/ (gcc)
-# ~/Android/Sdk/ndk/20.1.5948944/sysroot/usr/include/ (gcc)
-# ~/Android/Sdk/ndk/20.1.5948944/sysroot/usr/lib/aarch64-linux-android/libc.a (gcc)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/aarch64-linux-android-4.9/prebuilt/linux-x86_64/aarch64-linux-android/bin/ld (gcc)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/aarch64-linux-android-4.9/prebuilt/linux-x86_64/bin/aarch64-linux-android-ld (gcc)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/bin/aarch64-linux-android-ld (*)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/aarch64-linux-android/bin/ld
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/bin/clang (*)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot (2)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/aarch64-linux-android/asm/types.h (*) (2,3)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a (*)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc++_shared.so (*)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/24/libc.a (*) (2)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/c++/v1/complex (*) (4)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/bin/lld (*)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/bin/clang (*)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot (2)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/aarch64-linux-android/asm/types.h (*) (2,3)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a (*)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/24/libc++.so (*) (2)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/24/libc.so (*) (2)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/c++/v1/complex (*) (4)
 #
 # (*) tested by this script
 #
-# (1) ANDROID_TOOLCHAIN_SYSROOT0 exposes all libs with standard FS layout usr/lib, but no include files
-#     -> ANDROID_TOOLCHAIN_SYSROOT0_LIB
-#
-# (2) ANDROID_TOOLCHAIN_SYSROOT1 exposes all libs but without standard FS layout, also exposes include files 
+# (2) ANDROID_TOOLCHAIN_SYSROOT1 exposes all libs with standard FS layout usr/lib and usr/include
 #     -> ANDROID_TOOLCHAIN_SYSROOT1_INC
+#     -> ANDROID_TOOLCHAIN_SYSROOT1_LIB1
+#     -> ANDROID_TOOLCHAIN_SYSROOT1_LIB2
 #
 # (3) ANDROID_TOOLCHAIN_SYSROOT1 also exposes the arch dependent include files, i.e. asm/types.h etc
 #     -> ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH
@@ -91,16 +82,14 @@
 #     LLVM's c++ headers must come before other system header!
 #     Also see https://github.com/android/ndk/issues/452 and https://gitlab.kitware.com/cmake/cmake/issues/17059
 #
-# Native libraries of (1) and (2) are identical
-#
 # Having
 #   ANDROID_HOME=~/Android/Sdk
-#   ANDROID_API_LEVEL 24
+#   ANDROID_API_LEVEL 26
 #   ANDROID_HOST_TAG linux-x86_64
 #   ANDROID_ABI arm64-v8a
 # Using derived values of
-#   ANDROID_BUILD_TOOLS_VERSION=29.0.2
-#   ANDROID_NDK_VERSION=20.1.5948944
+#   ANDROID_BUILD_TOOLS_VERSION=36.0.0
+#   ANDROID_NDK_VERSION=29.0.13599879
 #   ANDROID_TOOLCHAIN_NAME aarch64-linux-android
 #   ANDROID_TOOLCHAIN_PLATFORM_NAME=arm64
 #   ANDROID_SYSROOT_ABI=arm64
@@ -111,7 +100,7 @@ NDK_TOOLCHAIN_VERSION=clang
 echo "Setting NDK_TOOLCHAIN_VERSION to ${NDK_TOOLCHAIN_VERSION} default!"
 
 if [ -z "${ANDROID_API_LEVEL}" ] ; then
-    ANDROID_API_LEVEL=24
+    ANDROID_API_LEVEL=26
     echo "Setting undefined ANDROID_API_LEVEL to ${ANDROID_API_LEVEL} default!"
 fi
 if [ -z "${ANDROID_HOST_TAG}" ] ; then
@@ -166,8 +155,6 @@ echo
 echo Preset-2
 echo   ANDROID_BUILDTOOLS_ROOT ${ANDROID_BUILDTOOLS_ROOT}
 echo   ANDROID_TOOLCHAIN_ROOT ${ANDROID_TOOLCHAIN_ROOT}
-echo   ANDROID_TOOLCHAIN_SYSROOT0 ${ANDROID_TOOLCHAIN_SYSROOT0}
-echo   ANDROID_TOOLCHAIN_SYSROOT0_LIB ${ANDROID_TOOLCHAIN_SYSROOT0_LIB}
 echo   ANDROID_TOOLCHAIN_SYSROOT1 ${ANDROID_TOOLCHAIN_SYSROOT1}
 echo   ANDROID_TOOLCHAIN_SYSROOT1_INC ${ANDROID_TOOLCHAIN_SYSROOT1_INC}
 echo   ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH ${ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH}
@@ -185,14 +172,14 @@ check_exists() {
 }
 
 if [ -z "${ANDROID_HOME}" ] ; then
-    if [ -e ${HOME}/Android/Sdk ] ; then
-        ANDROID_HOME=${HOME}/Android/Sdk
-    elif [ -e /opt-linux-x86_64/android-sdk-linux_x86_64 ] ; then
+    if [ -e /opt-linux-x86_64/android-sdk-linux_x86_64 ] ; then
         ANDROID_HOME=/opt-linux-x86_64/android-sdk-linux_x86_64
     elif [ -e /opt/android-sdk-linux_x86_64 ] ; then
         ANDROID_HOME=/opt/android-sdk-linux_x86_64
     elif [ -e /usr/local/android-sdk-linux_x86_64 ] ; then
         ANDROID_HOME=/usr/local/android-sdk-linux_x86_64
+    elif [ -e ${HOME}/Android/Sdk ] ; then
+        ANDROID_HOME=${HOME}/Android/Sdk
     else 
         echo ANDROID_HOME is not specified and does not exist in default locations
         exit 1
@@ -204,8 +191,8 @@ fi
 
 unset ANDROID_BUILD_TOOLS_VERSION
 if [ -z "${ANDROID_BUILD_TOOLS_VERSION}" ] ; then
-    # basename $(dirname `find /home/sven/Android/Sdk/build-tools -name zipalign | sort -u | tail -n1`)
-    fzipalign=`find ${ANDROID_HOME}/build-tools -name zipalign | sort -u | tail -n1`
+    # basename $(dirname `find -L /home/sven/Android/Sdk/build-tools -name zipalign | sort -u | tail -n1`)
+    fzipalign=`find -L ${ANDROID_HOME}/build-tools -name zipalign | sort -u | tail -n1`
     if [ ! -z "${fzipalign}" ] ; then
         dzipalign=`dirname ${fzipalign}`
         vzipalign=`basename ${dzipalign}`
@@ -224,18 +211,18 @@ if [ -z "${ANDROID_NDK}" ] ; then
     # Generic android-ndk
     #
     if [ -e ${ANDROID_HOME}/ndk ] ; then
-        # basename $(dirname `find ndk -name toolchains -a -type d | sort -u | tail -n1`)
-        d2toolchains=`find ${ANDROID_HOME}/ndk -name toolchains -a -type d | sort -u | tail -n1`
+        # basename $(dirname `find -L ndk -name toolchains -a -type d | sort -u | tail -n1`)
+        d2toolchains=`find -L ${ANDROID_HOME}/ndk -name toolchains -a -type d | sort -u | tail -n1`
         if [ ! -z "${d2toolchains}" ] ; then
             dtoolchains=`dirname ${d2toolchains}`
             vtoolchains=`basename ${dtoolchains}`
-            # ~/Android/Sdk/ndk/20.1.5948944/sysroot/usr/lib/aarch64-linux-android/libc.a (*)
-            if [ -e ${ANDROID_HOME}/ndk/${vtoolchains}/sysroot/usr/lib/aarch64-linux-android/libc.a ] ; then
+            # ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a (*)
+            if [ -e ${ANDROID_HOME}/ndk/${vtoolchains}/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a ] ; then
                 ANDROID_NDK_VERSION=${vtoolchains}
             fi
         fi
         if [ -z "${ANDROID_NDK_VERSION}" ] ; then
-            echo ANDROID_NDK_VERSION ${ANDROID_HOME}/ndk/ANDROID_NDK_VERSION/sysroot/usr/lib/aarch64-linux-android/libc.a does not exist
+            echo ANDROID_NDK_VERSION ${ANDROID_HOME}/ndk/ANDROID_NDK_VERSION/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a does not exist
         else
             ANDROID_NDK=${ANDROID_HOME}/ndk/${vtoolchains}
         fi
@@ -262,9 +249,6 @@ fi
 ANDROID_BUILDTOOLS_ROOT=${ANDROID_HOME}/build-tools/${ANDROID_BUILD_TOOLS_VERSION}
 ANDROID_TOOLCHAIN_ROOT=${ANDROID_NDK}/toolchains/llvm/prebuilt/${ANDROID_HOST_TAG}
 
-ANDROID_TOOLCHAIN_SYSROOT0=${ANDROID_NDK}/platforms/android-${ANDROID_API_LEVEL}/arch-${ANDROID_SYSROOT_ABI}
-ANDROID_TOOLCHAIN_SYSROOT0_LIB=${ANDROID_TOOLCHAIN_SYSROOT0}/usr/lib
-
 ANDROID_TOOLCHAIN_SYSROOT1=${ANDROID_TOOLCHAIN_ROOT}/sysroot
 ANDROID_TOOLCHAIN_SYSROOT1_INC=${ANDROID_TOOLCHAIN_SYSROOT1}/usr/include
 ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH=${ANDROID_TOOLCHAIN_SYSROOT1_INC}/${ANDROID_TOOLCHAIN_NAME}
@@ -272,31 +256,27 @@ ANDROID_TOOLCHAIN_SYSROOT1_INC_STL=${ANDROID_TOOLCHAIN_SYSROOT1_INC}/c++/v1
 ANDROID_TOOLCHAIN_SYSROOT1_LIB1=${ANDROID_TOOLCHAIN_SYSROOT1}/usr/lib/${ANDROID_TOOLCHAIN_NAME}/${ANDROID_API_LEVEL}
 ANDROID_TOOLCHAIN_SYSROOT1_LIB2=${ANDROID_TOOLCHAIN_SYSROOT1}/usr/lib/${ANDROID_TOOLCHAIN_NAME}
 
-# ~/Android/Sdk/build-tools/29.0.2/zipalign (*)
+# ~/Android/Sdk/build-tools/36.0.0/zipalign (*)
 check_exists ${ANDROID_BUILDTOOLS_ROOT}/zipalign
 
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/bin/aarch64-linux-android-ld (*)
-check_exists ${ANDROID_TOOLCHAIN_ROOT}/bin/${ANDROID_TOOLCHAIN_NAME}-ld
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/bin/lld (*)
+check_exists ${ANDROID_TOOLCHAIN_ROOT}/bin/lld
 
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/bin/clang (*)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/bin/clang (*)
 check_exists ${ANDROID_TOOLCHAIN_ROOT}/bin/clang
 
-# ~/Android/Sdk/ndk/20.1.5948944/platforms/android-24/arch-arm64/usr/lib/libc.a (*)
-check_exists ${ANDROID_TOOLCHAIN_SYSROOT0_LIB}/libc.a
-
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/aarch64-linux-android/asm/types.h (*) (2)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/aarch64-linux-android/asm/types.h (*) (2)
 check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH}/asm/types.h
 
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/c++/v1/complex (*) (4)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/include/c++/v1/complex (*) (4)
 check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_INC_STL}/complex
 
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/24/libc.a (*)
-check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_LIB1}/libc.a
-
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a (*)
-# ~/Android/Sdk/ndk/20.1.5948944/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc++_shared.so (*)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/libc.a (*)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/24/libc++.so (*) (2)
+# ~/Android/Sdk/ndk/29.0.13599879/toolchains/llvm/prebuilt/linux-x86_64/sysroot/usr/lib/aarch64-linux-android/24/libc.so (*) (2)
 check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_LIB2}/libc.a
-check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_LIB2}/libc++_shared.so
+check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_LIB1}/libc++.a
+check_exists ${ANDROID_TOOLCHAIN_SYSROOT1_LIB1}/libc.so
 
 export ANDROID_HOME
 export ANDROID_API_LEVEL
@@ -312,8 +292,6 @@ export ANDROID_NDK
 
 export ANDROID_BUILDTOOLS_ROOT
 export ANDROID_TOOLCHAIN_ROOT
-export ANDROID_TOOLCHAIN_SYSROOT0
-export ANDROID_TOOLCHAIN_SYSROOT0_LIB
 export ANDROID_TOOLCHAIN_SYSROOT1
 export ANDROID_TOOLCHAIN_SYSROOT1_INC
 export ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH
@@ -338,8 +316,6 @@ echo
 echo Postset-2
 echo   ANDROID_BUILDTOOLS_ROOT ${ANDROID_BUILDTOOLS_ROOT}
 echo   ANDROID_TOOLCHAIN_ROOT ${ANDROID_TOOLCHAIN_ROOT}
-echo   ANDROID_TOOLCHAIN_SYSROOT0 ${ANDROID_TOOLCHAIN_SYSROOT0}
-echo   ANDROID_TOOLCHAIN_SYSROOT0_LIB ${ANDROID_TOOLCHAIN_SYSROOT0_LIB}
 echo   ANDROID_TOOLCHAIN_SYSROOT1 ${ANDROID_TOOLCHAIN_SYSROOT1}
 echo   ANDROID_TOOLCHAIN_SYSROOT1_INC ${ANDROID_TOOLCHAIN_SYSROOT1_INC}
 echo   ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH ${ANDROID_TOOLCHAIN_SYSROOT1_INC_ARCH}
