@@ -171,7 +171,7 @@ public class IOUtil {
      */
 
     /**
-     * Copy the specified URL resource to the specified output file. The total
+     * Copy the complete specified URL resource to the specified output file. The total
      * number of bytes written is returned.
      *
      * @param conn the open URLConnection
@@ -185,7 +185,7 @@ public class IOUtil {
         int totalNumBytes = 0;
         final InputStream in = new BufferedInputStream(conn.getInputStream());
         try {
-            totalNumBytes = copyStream2File(in, outFile, conn.getContentLength());
+            totalNumBytes = copyStream2File(in, outFile);
         } finally {
             in.close();
         }
@@ -193,51 +193,47 @@ public class IOUtil {
     }
 
     /**
-     * Copy the specified input stream to the specified output file. The total
+     * Copy the complete specified input stream to the specified output file. The total
      * number of bytes written is returned.
      *
      * @param in the source
      * @param outFile the destination
-     * @param totalNumBytes informal number of expected bytes, maybe used for user feedback while processing. -1 if unknown
      * @return
      * @throws IOException
      */
-    public static int copyStream2File(final InputStream in, final File outFile, int totalNumBytes) throws IOException {
+    public static int copyStream2File(final InputStream in, final File outFile) throws IOException {
         final OutputStream out = new BufferedOutputStream(new FileOutputStream(outFile));
         try {
-            totalNumBytes = copyStream2Stream(in, out, totalNumBytes);
+            return copyStream2Stream(in, out);
         } finally {
             out.close();
         }
-        return totalNumBytes;
     }
 
     /**
-     * Copy the specified input stream to the specified output stream. The total
+     * Copy the complete specified input stream to the specified output stream. The total
      * number of bytes written is returned.
      *
      * @param in the source
      * @param out the destination
-     * @param totalNumBytes informal number of expected bytes, maybe used for user feedback while processing. -1 if unknown
      * @return
      * @throws IOException
      */
-    public static int copyStream2Stream(final InputStream in, final OutputStream out, final int totalNumBytes) throws IOException {
-        return copyStream2Stream(Platform.getMachineDataInfo().pageSizeInBytes(), in, out, totalNumBytes);
+    public static int copyStream2Stream(final InputStream in, final OutputStream out) throws IOException {
+        return copyStream2Stream(Platform.getMachineDataInfo().pageSizeInBytes(), in, out);
     }
 
     /**
-     * Copy the specified input stream to the specified output stream. The total
+     * Copy the complete specified input stream to the specified output stream. The total
      * number of bytes written is returned.
      *
      * @param bufferSize the intermediate buffer size, should be {@link MachineDataInfo#pageSizeInBytes()} for best performance.
      * @param in the source
      * @param out the destination
-     * @param totalNumBytes informal number of expected bytes, maybe used for user feedback while processing. -1 if unknown
      * @return
      * @throws IOException
      */
-    public static int copyStream2Stream(final int bufferSize, final InputStream in, final OutputStream out, final int totalNumBytes) throws IOException {
+    public static int copyStream2Stream(final int bufferSize, final InputStream in, final OutputStream out) throws IOException {
         final byte[] buf = new byte[bufferSize];
         int numBytes = 0;
         while (true) {
@@ -261,7 +257,7 @@ public class IOUtil {
     }
 
     /**
-     * Copy the specified input stream to a byte array, which is being returned.
+     * Copy the complete specified input stream to a byte array, which is being returned.
      */
     public static byte[] copyStream2ByteArray(InputStream stream) throws IOException {
         if( !(stream instanceof BufferedInputStream) ) {
@@ -294,8 +290,7 @@ public class IOUtil {
     }
 
     /**
-     * Copy the specified input stream to a NIO ByteBuffer w/ native byte order, which is being returned.
-     * <p>The implementation creates the ByteBuffer w/ {@link #copyStream2ByteArray(InputStream)}'s returned byte array.</p>
+     * Copy the complete specified input stream to a NIO ByteBuffer w/ native byte order, which is being returned.
      *
      * @param stream input stream, which will be wrapped into a BufferedInputStream, if not already done.
      */
@@ -304,11 +299,10 @@ public class IOUtil {
     }
 
     /**
-     * Copy the specified input stream to a NIO ByteBuffer w/ native byte order, which is being returned.
-     * <p>The implementation creates the ByteBuffer w/ {@link #copyStream2ByteArray(InputStream)}'s returned byte array.</p>
+     * Copy the complete specified input stream to a NIO ByteBuffer w/ native byte order, which is being returned.
      *
      * @param stream input stream, which will be wrapped into a BufferedInputStream, if not already done.
-     * @param initialCapacity initial buffer capacity in bytes, if &gt; available bytes
+     * @param initialCapacity initial buffer capacity in bytes, if &lt; currently available bytes, initial buffer capacity is set to currently available bytes.
      */
     public static ByteBuffer copyStream2ByteBuffer(InputStream stream, int initialCapacity) throws IOException {
         if( !(stream instanceof BufferedInputStream) ) {
@@ -343,6 +337,39 @@ public class IOUtil {
         return data;
     }
 
+    /**
+     * Copy the specified input stream chunk to a NIO ByteBuffer w/ native byte order, which is being returned.
+     *
+     * @param stream input stream, which will be wrapped into a BufferedInputStream, if not already done.
+     * @param skipBytes initial bytes to skip from input stream.
+     * @param byteCount bytes to copy starting after skipBytes.
+     */
+    public static ByteBuffer copyStreamChunk2ByteBuffer(InputStream stream, int skipBytes, int byteCount) throws IOException {
+        if( !(stream instanceof BufferedInputStream) ) {
+            stream = new BufferedInputStream(stream);
+        }
+        final MachineDataInfo machine = Platform.getMachineDataInfo();
+        final ByteBuffer data = Buffers.newDirectByteBuffer( machine.pageAlignedSize( byteCount ) );
+        final byte[] chunk = new byte[machine.pageSizeInBytes()];
+        int numRead = 1; // EOS: -1 == numRead, EOF maybe reached earlier w/ 0 == numRead
+        while ( numRead > 0 && skipBytes > 0 ) {
+            final int chunk2Read = Math.min(machine.pageSizeInBytes(), skipBytes);
+            numRead = stream.read(chunk, 0, chunk2Read);
+            skipBytes -= numRead;
+        }
+        while ( numRead > 0 && byteCount > 0 ) {
+            final int chunk2Read = Math.min(machine.pageSizeInBytes(), byteCount);
+            numRead = stream.read(chunk, 0, chunk2Read);
+            if (numRead > 0) {
+                data.put(chunk, 0, numRead);
+            }
+            byteCount -= numRead;
+        }
+
+        data.flip();
+        return data;
+    }
+
     /***
      *
      * RESOURCE / FILE NAME STUFF
@@ -765,12 +792,28 @@ public class IOUtil {
               return ".sh";
         }
     }
+    private static String getExeTestShellCodeUnix(final String test) {
+        if( testExeFile(new File(test)) ) {
+              return "#!"+test+PlatformPropsImpl.NEWLINE;
+        }
+        return null;
+    }
     private static String getExeTestShellCode() {
+        if( PlatformPropsImpl.OS_TYPE == Platform.OSType.WINDOWS ) {
+            return "echo off"+PlatformPropsImpl.NEWLINE;
+        }
+        final String res = getExeTestShellCodeUnix("/usr/bin/true");
+        if( null != res ) {
+            return res;
+        }
+        return getExeTestShellCodeUnix("/bin/true");
+    }
+    private static String getExeNativePath(final String canonicalPath) {
         switch(PlatformPropsImpl.OS_TYPE) {
             case WINDOWS:
-              return "echo off"+PlatformPropsImpl.NEWLINE;
+              return "\""+canonicalPath+"\"";
             default:
-              return "#!/bin/true"+PlatformPropsImpl.NEWLINE;
+              return canonicalPath;
         }
     }
     private static String[] getExeTestCommandArgs(final String scriptFile) {
@@ -901,6 +944,27 @@ public class IOUtil {
         }
         return true;
     }
+    /**
+     * Test whether executable {@code file} exists, no OS executable tests performed, just permissions via Java
+     *
+     * @param file
+     * @return
+     */
+    public static boolean testExeFile(final File file) {
+        if (!file.exists()) {
+            if(DEBUG) {
+                System.err.println("IOUtil.testFile: <"+file.getAbsolutePath()+">: does not exist");
+            }
+            return false;
+        }
+        if (!file.canExecute()) {
+            if(DEBUG) {
+                System.err.println("IOUtil.testFile: <"+file.getAbsolutePath()+">: can't be executed");
+            }
+            return false;
+        }
+        return true;
+    }
 
     public static class StreamMonitor implements Runnable {
         private final InputStream[] istreams;
@@ -1006,6 +1070,7 @@ public class IOUtil {
 
         final long t0 = debug ? System.currentTimeMillis() : 0;
         final File exeTestFile;
+        String exeNativePath;
         final boolean existingExe;
         try {
             final File permExeTestFile = DEBUG_EXE_EXISTING_FILE ? new File(dir, "jogamp_exe_tst"+getExeTestFileSuffix()) : null;
@@ -1017,6 +1082,7 @@ public class IOUtil {
                 existingExe = false;
                 fillExeTestFile(exeTestFile);
             }
+            exeNativePath = getExeNativePath( exeTestFile.getCanonicalPath() );
         } catch (final SecurityException se) {
             throw se; // fwd Security exception
         } catch (final IOException e) {
@@ -1045,7 +1111,7 @@ public class IOUtil {
                     // Using 'Process.exec(String[])' avoids StringTokenizer of 'Process.exec(String)'
                     // and hence splitting up command by spaces!
                     // Note: All no-exec cases throw an IOExceptions at ProcessBuilder.start(), i.e. below exec() call!
-                    pr = Runtime.getRuntime().exec( getExeTestCommandArgs( exeTestFile.getCanonicalPath() ), null, null );
+                    pr = Runtime.getRuntime().exec( getExeTestCommandArgs( exeNativePath ), null, null );
                     if( DEBUG_EXE && !DEBUG_EXE_NOSTREAM ) {
                         new StreamMonitor(new InputStream[] { pr.getInputStream(), pr.getErrorStream() }, System.err, "Exe-Tst: ");
                     }
@@ -1062,7 +1128,7 @@ public class IOUtil {
                     t2 = debug ? System.currentTimeMillis() : 0;
                     res = -3;
                     if( debug ) {
-                        System.err.println("IOUtil.testDirExec: <"+exeTestFile.getAbsolutePath()+">: Caught "+t.getClass().getSimpleName()+": "+t.getMessage());
+                        System.err.println("IOUtil.testDirExec: <"+exeNativePath+">: Caught "+t.getClass().getSimpleName()+": "+t.getMessage());
                         t.printStackTrace();
                     }
                 } finally {
@@ -1088,7 +1154,7 @@ public class IOUtil {
         }
         if( debug ) {
             final long t3 = System.currentTimeMillis();
-            System.err.println("IOUtil.testDirExec(): test-exe <"+exeTestFile.getAbsolutePath()+">, existingFile "+existingExe+", isNioExec "+isNioExec+", returned "+exitValue);
+            System.err.println("IOUtil.testDirExec(): test-exe <"+exeNativePath+">, existingFile "+existingExe+", isNioExec "+isNioExec+", returned "+exitValue);
             System.err.println("IOUtil.testDirExec(): abs-path <"+dir.getAbsolutePath()+">: res "+res+" -> "+ok);
             System.err.println("IOUtil.testDirExec(): total "+(t3-t0)+"ms, create "+(t1-t0)+"ms, fill "+(t2-t1)+"ms, execute "+(t3-t2)+"ms");
         }
