@@ -45,6 +45,16 @@ public class JogampVersion {
     public static final Attributes.Name IMPLEMENTATION_BRANCH = new Attributes.Name("Implementation-Branch");
     /** See {@link #getImplementationCommit()} */
     public static final Attributes.Name IMPLEMENTATION_COMMIT = new Attributes.Name("Implementation-Commit");
+    /** See {@link #getImplementationSHASources()} */
+    public static final Attributes.Name IMPLEMENTATION_SHA_SOURCES = new Attributes.Name("Implementation-SHA-Sources");
+    /** See {@link #getImplementationSHAClasses()} */
+    public static final Attributes.Name IMPLEMENTATION_SHA_CLASSES = new Attributes.Name("Implementation-SHA-Classes");
+    /** See {@link #getImplementationSHAClassesThis()} */
+    public static final Attributes.Name IMPLEMENTATION_SHA_CLASSES_THIS = new Attributes.Name("Implementation-SHA-Classes-this");
+    /** See {@link #getImplementationSHANatives()} */
+    public static final Attributes.Name IMPLEMENTATION_SHA_NATIVES = new Attributes.Name("Implementation-SHA-Natives");
+    /** See {@link #getImplementationSHANativesThis()} */
+    public static final Attributes.Name IMPLEMENTATION_SHA_NATIVES_THIS = new Attributes.Name("Implementation-SHA-Natives-this");
 
     /** For FAT JogAmp jar files */
     private static final String packageNameFAT = "com.jogamp";
@@ -57,22 +67,20 @@ public class JogampVersion {
 
     private final String androidPackageVersionName;
 
-    protected JogampVersion(final String packageName, final Manifest mf) {
+    protected JogampVersion(final Manifest mf) {
         if( null != mf ) {
             // use provided valid data
             this.mf = mf;
-            this.packageName = packageName;
+            this.packageName = VersionUtil.getExtensionName(mf);
         } else {
-            // try FAT jar file
-            final Manifest fatMF = VersionUtil.getManifest(JogampVersion.class.getClassLoader(), packageNameFAT);
+            // try FAT jar file and accept first Manifest w/ extension-name if none matches
+            final Manifest fatMF = VersionUtil.getManifest(JogampVersion.class.getClassLoader(), new String[] { packageNameFAT }, true);
             if( null != fatMF ) {
-                // use FAT jar file
                 this.mf = fatMF;
-                this.packageName = packageNameFAT;
+                this.packageName = VersionUtil.getExtensionName(fatMF);
             } else {
-                // use faulty data, unresolvable ..
                 this.mf = new Manifest();
-                this.packageName = packageName;
+                this.packageName = "unknown";
             }
         }
         this.hash = this.mf.hashCode();
@@ -155,6 +163,41 @@ public class JogampVersion {
         return this.getAttribute(JogampVersion.IMPLEMENTATION_COMMIT);
     }
 
+    /**
+     * Returns the SHA of all concatenated source files of the whole project
+     */
+    public final String getImplementationSHASources() {
+        return this.getAttribute(JogampVersion.IMPLEMENTATION_SHA_SOURCES);
+    }
+
+    /**
+     * Returns the SHA of all concatenated class files of all build classes
+     */
+    public final String getImplementationSHAClasses() {
+        return this.getAttribute(JogampVersion.IMPLEMENTATION_SHA_CLASSES);
+    }
+
+    /**
+     * Returns the SHA of all concatenated class files of the local (jar) package subset
+     */
+    public final String getImplementationSHAClassesThis() {
+        return this.getAttribute(JogampVersion.IMPLEMENTATION_SHA_CLASSES_THIS);
+    }
+
+    /**
+     * Returns the SHA of all concatenated native library files of all build libs
+     */
+    public final String getImplementationSHANatives() {
+        return this.getAttribute(JogampVersion.IMPLEMENTATION_SHA_NATIVES);
+    }
+
+    /**
+     * Returns the SHA of all concatenated native library files of the local (jar) package subset
+     */
+    public final String getImplementationSHANativesThis() {
+        return this.getAttribute(JogampVersion.IMPLEMENTATION_SHA_NATIVES_THIS);
+    }
+
     public final String getImplementationTitle() {
         return this.getAttribute(Attributes.Name.IMPLEMENTATION_TITLE);
     }
@@ -220,11 +263,24 @@ public class JogampVersion {
         sb.append("Implementation Build: ").append(getImplementationBuild()).append(nl);
         sb.append("Implementation Branch: ").append(getImplementationBranch()).append(nl);
         sb.append("Implementation Commit: ").append(getImplementationCommit()).append(nl);
-        if(null != getAndroidPackageVersionName()) {
-            sb.append("Android Package Version: ").append(getAndroidPackageVersionName()).append(nl);
-        }
+
+        addOptionalTag(sb, "Implementation SHA Sources", () -> { return getImplementationSHASources(); });
+        addOptionalTag(sb, "Implementation SHA Classes", () -> { return getImplementationSHAClasses(); });
+        addOptionalTag(sb, "Implementation SHA Classes-this", () -> { return getImplementationSHAClassesThis(); });
+        addOptionalTag(sb, "Implementation SHA Natives", () -> { return getImplementationSHANatives(); });
+        addOptionalTag(sb, "Implementation SHA Natives-this", () -> { return getImplementationSHANativesThis(); });
+        addOptionalTag(sb, "Android Package Version", () -> { return getAndroidPackageVersionName(); });
         return sb;
     }
+    private static interface TagProvider {
+        public String get();
+    }
+    private static void addOptionalTag(final StringBuilder sb, final String title, final TagProvider tag) {
+        final String tagName = tag.get();
+        if( null != tagName ) {
+            sb.append(title+": ").append(tagName).append(Platform.getNewline());
+        }
+    }
 
     public StringBuilder toString(StringBuilder sb) {
         if(null==sb) {
