@@ -179,10 +179,22 @@ public abstract class CompoundType extends MemoryLayoutType implements Cloneable
     return fields.get(i);
   }
 
+  /** Returns the <i>name</i> matching field of this type. */
+  public Field getField(final String name) {
+    for(final Field f : fields ) {
+        if( f.getName().equals(name) ) {
+            return f;
+        }
+    }
+    return null;
+  }
+
   /** Adds a field to this type. */
   public void addField(final Field f) {
     if (bodyParsed) {
-      throw new IllegalStateException("Body of this CompoundType has been already closed");
+      throw new IllegalStateException(String.format(
+              "Body of this CompoundType (%s) has been already closed (Field supplied %s)", this, f
+      ));
     }
     if (fields == null) {
       fields = new ArrayList<Field>();
@@ -198,7 +210,9 @@ public abstract class CompoundType extends MemoryLayoutType implements Cloneable
    */
   public void setBodyParsed() throws IllegalStateException {
     if (bodyParsed) {
-        throw new IllegalStateException("Body of this CompoundType has been already closed");
+      throw new IllegalStateException(String.format(
+              "Body of this CompoundType (%s) has been already closed", this
+      ));
     }
     bodyParsed = true;
   }
