@@ -1,6 +1,6 @@
-/*
+/**
+ * Copyright (c) 2010-2023 JogAmp Community. All rights reserved.
  * Copyright (c) 2003 Sun Microsystems, Inc. All Rights Reserved.
- * Copyright (c) 2010 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -125,14 +125,35 @@ public class PointerType extends Type implements Cloneable {
 
     @Override
     public final Type getTargetType() {
-        return targetType;
+        if( isFunctionPointer() ) {
+            return this;
+        } else {
+            return targetType;
+        }
     }
 
     @Override
-    public final Type getBaseElementType() {
-        return targetType.getBaseElementType();
+    public final Type getBaseType() {
+        if( isFunctionPointer() ) {
+            return this;
+        } else {
+            return targetType.getBaseType();
+        }
     }
 
+    @Override
+    public Type getArrayBaseOrPointerTargetType() {
+        return getTargetType();
+    }
+
+    @Override
+    public FunctionType getTargetFunction() {
+        if( isFunctionPointer() ) {
+            return targetType.asFunction();
+        } else {
+            return null;
+        }
+    }
     @Override
     public final boolean isFunctionPointer() {
         return targetType.isFunction();
@@ -152,7 +173,7 @@ public class PointerType extends Type implements Cloneable {
         }
     }
     private String toStringInt() {
-        if (!targetType.isFunction()) {
+        if (!isFunctionPointer()) {
             return targetType.getCName(true) + " * " + getCVAttributesString();
         } else {
             // return toString(null, null); // this is a pointer to an unnamed function
@@ -164,7 +185,7 @@ public class PointerType extends Type implements Cloneable {
     string (i.e., "__stdcall") is optional and is generally only
     needed on Windows. */
     public String toString(final String functionName, final String callingConvention) {
-        if (!targetType.isFunction()) {
+        if (!isFunctionPointer()) {
             throw new RuntimeException("<Internal error or misuse> This method is only for use when printing function pointers");
         }
         return ((FunctionType) targetType).toString(functionName, callingConvention, false, true);
