@@ -496,10 +496,10 @@ public abstract class PlatformPropsImpl {
     }
     private static File findSysLib(final String libName) {
         final ClassLoader cl = PlatformPropsImpl.class.getClassLoader();
-        final List<String> possibleLibPaths = NativeLibrary.enumerateLibraryPaths(libName, libName, libName, true, cl);
+        final List<NativeLibrary.LibPath> possibleLibPaths = NativeLibrary.enumerateLibraryPaths(libName, libName, libName, true, cl);
         for(int i=0; i<possibleLibPaths.size(); i++) {
-            final String libPath = possibleLibPaths.get(i);
-            final File lib = new File(libPath);
+            final NativeLibrary.LibPath libPath = possibleLibPaths.get(i);
+            final File lib = new File(libPath.path);
             if(DEBUG) {
                 System.err.println("findSysLib #"+i+": test "+lib);
             }
