@@ -27,6 +27,8 @@
  */
 package jogamp.common.os;
 
+import com.jogamp.common.os.NativeLibrary.LibPath;
+
 public final class PosixDynamicLinkerImpl extends UnixDynamicLinkerImpl {
 
   private static final long RTLD_DEFAULT = 0;
@@ -38,13 +40,13 @@ public final class PosixDynamicLinkerImpl extends UnixDynamicLinkerImpl {
   private static final int RTLD_GLOBAL   = 0x00100;
 
   @Override
-  protected final long openLibraryLocalImpl(final String pathname) throws SecurityException {
-    return dlopen(pathname, RTLD_LAZY | RTLD_LOCAL);
+  protected final long openLibraryLocalImpl(final LibPath libpath) throws SecurityException {
+    return dlopen(libpath.path, RTLD_LAZY | RTLD_LOCAL);
   }
 
   @Override
-  protected final long openLibraryGlobalImpl(final String pathname) throws SecurityException {
-    return dlopen(pathname, RTLD_LAZY | RTLD_GLOBAL);
+  protected final long openLibraryGlobalImpl(final LibPath libpath) throws SecurityException {
+    return dlopen(libpath.path, RTLD_LAZY | RTLD_GLOBAL);
   }
 
   @Override
