@@ -54,6 +54,26 @@ public class BindingJNILibLoader extends JNILibLoaderBase {
             }
         });
     }
+
+    public static void loadBindingtest2p1() {
+        SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
+            @Override
+            public Object run() {
+                loadLibrary("Bindingtest2p1", null, true, BindingJNILibLoader.class.getClassLoader());
+                return null;
+            }
+        });
+    }
+
+    public static void loadBindingtest2p2() {
+        SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
+            @Override
+            public Object run() {
+                loadLibrary("Bindingtest2p2", null, true, BindingJNILibLoader.class.getClassLoader());
+                return null;
+            }
+        });
+    }
 }
 
 
