@@ -37,6 +37,7 @@ import com.jogamp.common.util.RunnableExecutor;
 import com.jogamp.common.util.TestIOUtil01;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 
 import org.junit.AfterClass;
@@ -58,6 +59,7 @@ public class Test1p2DynamicLibraryBundle extends BaseClass {
     public static void chapter__TestLoadLibrary() throws Exception {
         dlb = new DynamicLibraryBundle(new Test1DynLibBundleInfo());
         Assert.assertTrue("DynamicLibraryBundle failed", dlb.isLibComplete());
+        System.err.println("Loaded: "+dlb.getToolLibraries());
 
         Bindingtest1p2Impl.resetProcAddressTable(dlb);
     }
@@ -169,16 +171,21 @@ public class Test1p2DynamicLibraryBundle extends BaseClass {
     }
 
     @Test
-    public void chapter15TestTKMixed() throws Exception {
-        chapter15TestTKMixed(new Bindingtest1p2Impl());
+    public void chapter14TestTKMixed() throws Exception {
+        chapter14TestTKMixed(new Bindingtest1p2Impl());
     }
 
     /**
      * Test Custom JNI Code invocation
      */
     @Test
-    public void chapter14TestCustomJNICode() throws Exception {
-        chapter14TestCustomJNICode(new Bindingtest1p2Impl());
+    public void chapter15TestCustomJNICode() throws Exception {
+        chapter15TestCustomJNICode(new Bindingtest1p2Impl());
+    }
+
+    @Test
+    public void chapter16TestPascalString() throws Exception {
+        chapter16TestPascalString(new Bindingtest1p2Impl());
     }
 
     /**
@@ -261,6 +268,9 @@ public class Test1p2DynamicLibraryBundle extends BaseClass {
             return libNamesList;
         }
 
+        @Override
+        public List<String> getSymbolForToolLibPath() { return Arrays.asList("testXID"); }
+
         @Override
         public final List<String> getToolGetProcAddressFuncNameList() {
             return null;
